@@ -30,15 +30,18 @@ states, visit :ref:`the Audit State machine <audit_state_machine>`.
 """
 
 import datetime
+from dateutil import tz
 
+from http import HTTPStatus
+from oslo_log import log
+from oslo_utils import timeutils
 import pecan
 from pecan import rest
 import wsme
 from wsme import types as wtypes
+from wsme import utils as wutils
 import wsmeext.pecan as wsme_pecan
 
-from oslo_log import log
-
 from watcher._i18n import _
 from watcher.api.controllers import base
 from watcher.api.controllers import link
@@ -54,6 +57,27 @@ from watcher import objects
 LOG = log.getLogger(__name__)
 
 
+def _get_object_by_value(context, class_name, value):
+    if utils.is_uuid_like(value) or utils.is_int_like(value):
+        return class_name.get(context, value)
+    else:
+        return class_name.get_by_name(context, value)
+
+
+def hide_fields_in_newer_versions(obj):
+    """This method hides fields that were added in newer API versions.
+
+    Certain node fields were introduced at certain API versions.
+    These fields are only made available when the request's API version
+    matches or exceeds the versions when these fields were introduced.
+    """
+    if not api_utils.allow_start_end_audit_time():
+        obj.start_time = wtypes.Unset
+        obj.end_time = wtypes.Unset
+    if not api_utils.allow_force():
+        obj.force = wtypes.Unset
+
+
 class AuditPostType(wtypes.Base):
 
     name = wtypes.wsattr(wtypes.text, mandatory=False)
@@ -66,12 +90,12 @@ class AuditPostType(wtypes.Base):
 
     audit_type = wtypes.wsattr(wtypes.text, mandatory=True)
 
-    state = wsme.wsattr(wtypes.text, readonly=True,
-                        default=objects.audit.State.PENDING)
+    state = wtypes.wsattr(wtypes.text, readonly=True,
+                          default=objects.audit.State.PENDING)
 
     parameters = wtypes.wsattr({wtypes.text: types.jsontype}, mandatory=False,
                                default={})
-    interval = wsme.wsattr(types.interval_or_cron, mandatory=False)
+    interval = wtypes.wsattr(types.interval_or_cron, mandatory=False)
 
     scope = wtypes.wsattr(types.jsontype, readonly=True)
 
@@ -79,6 +103,12 @@ class AuditPostType(wtypes.Base):
 
     hostname = wtypes.wsattr(wtypes.text, readonly=True, mandatory=False)
 
+    start_time = wtypes.wsattr(datetime.datetime, mandatory=False)
+
+    end_time = wtypes.wsattr(datetime.datetime, mandatory=False)
+
+    force = wtypes.wsattr(bool, mandatory=False)
+
     def as_audit(self, context):
         audit_type_values = [val.value for val in objects.audit.AuditType]
         if self.audit_type not in audit_type_values:
@@ -93,6 +123,21 @@ class AuditPostType(wtypes.Base):
             raise exception.AuditIntervalNotSpecified(
                 audit_type=self.audit_type)
 
+        if self.audit_template_uuid and self.goal:
+            raise exception.Invalid('Either audit_template_uuid '
+                                    'or goal should be provided.')
+
+        if (self.audit_type == objects.audit.AuditType.ONESHOT.value and
+                (self.start_time not in (wtypes.Unset, None) or
+                    self.end_time not in (wtypes.Unset, None))):
+            raise exception.AuditStartEndTimeNotAllowed(
+                audit_type=self.audit_type)
+
+        if not api_utils.allow_start_end_audit_time():
+            for field in ('start_time', 'end_time'):
+                if getattr(self, field) not in (wtypes.Unset, None):
+                    raise exception.NotAcceptable()
+
         # If audit_template_uuid was provided, we will provide any
         # variables not included in the request, but not override
         # those variables that were included.
@@ -123,18 +168,19 @@ class AuditPostType(wtypes.Base):
         # Note: If audit name was not provided, used a default name
         if not self.name:
             if self.strategy:
-                strategy = objects.Strategy.get(context, self.strategy)
+                strategy = _get_object_by_value(context, objects.Strategy,
+                                                self.strategy)
                 self.name = "%s-%s" % (strategy.name,
-                                       datetime.datetime.utcnow().isoformat())
+                                       timeutils.utcnow().isoformat())
             elif self.audit_template_uuid:
                 audit_template = objects.AuditTemplate.get(
                     context, self.audit_template_uuid)
                 self.name = "%s-%s" % (audit_template.name,
-                                       datetime.datetime.utcnow().isoformat())
+                                       timeutils.utcnow().isoformat())
             else:
-                goal = objects.Goal.get(context, self.goal)
+                goal = _get_object_by_value(context, objects.Goal, self.goal)
                 self.name = "%s-%s" % (goal.name,
-                                       datetime.datetime.utcnow().isoformat())
+                                       timeutils.utcnow().isoformat())
         # No more than 63 characters
         if len(self.name) > 63:
             LOG.warning("Audit: %s length exceeds 63 characters",
@@ -149,7 +195,10 @@ class AuditPostType(wtypes.Base):
             strategy_id=self.strategy,
             interval=self.interval,
             scope=self.scope,
-            auto_trigger=self.auto_trigger)
+            auto_trigger=self.auto_trigger,
+            start_time=self.start_time,
+            end_time=self.end_time,
+            force=self.force)
 
 
 class AuditPatchType(types.JsonPatchType):
@@ -273,43 +322,53 @@ class Audit(base.APIBase):
     state = wtypes.text
     """This audit state"""
 
-    goal_uuid = wsme.wsproperty(
+    goal_uuid = wtypes.wsproperty(
         wtypes.text, _get_goal_uuid, _set_goal_uuid, mandatory=True)
     """Goal UUID the audit refers to"""
 
-    goal_name = wsme.wsproperty(
+    goal_name = wtypes.wsproperty(
         wtypes.text, _get_goal_name, _set_goal_name, mandatory=False)
     """The name of the goal this audit refers to"""
 
-    strategy_uuid = wsme.wsproperty(
+    strategy_uuid = wtypes.wsproperty(
         wtypes.text, _get_strategy_uuid, _set_strategy_uuid, mandatory=False)
     """Strategy UUID the audit refers to"""
 
-    strategy_name = wsme.wsproperty(
+    strategy_name = wtypes.wsproperty(
         wtypes.text, _get_strategy_name, _set_strategy_name, mandatory=False)
     """The name of the strategy this audit refers to"""
 
     parameters = {wtypes.text: types.jsontype}
     """The strategy parameters for this audit"""
 
-    links = wsme.wsattr([link.Link], readonly=True)
+    links = wtypes.wsattr([link.Link], readonly=True)
     """A list containing a self link and associated audit links"""
 
-    interval = wsme.wsattr(wtypes.text, mandatory=False)
+    interval = wtypes.wsattr(wtypes.text, mandatory=False)
     """Launch audit periodically (in seconds)"""
 
-    scope = wsme.wsattr(types.jsontype, mandatory=False)
+    scope = wtypes.wsattr(types.jsontype, mandatory=False)
     """Audit Scope"""
 
-    auto_trigger = wsme.wsattr(bool, mandatory=False, default=False)
+    auto_trigger = wtypes.wsattr(bool, mandatory=False, default=False)
     """Autoexecute action plan once audit is succeeded"""
 
-    next_run_time = wsme.wsattr(datetime.datetime, mandatory=False)
+    next_run_time = wtypes.wsattr(datetime.datetime, mandatory=False)
     """The next time audit launch"""
 
-    hostname = wsme.wsattr(wtypes.text, mandatory=False)
+    hostname = wtypes.wsattr(wtypes.text, mandatory=False)
     """Hostname the audit is running on"""
 
+    start_time = wtypes.wsattr(datetime.datetime, mandatory=False)
+    """The start time for continuous audit launch"""
+
+    end_time = wtypes.wsattr(datetime.datetime, mandatory=False)
+    """The end time that stopping continuous audit"""
+
+    force = wsme.wsattr(bool, mandatory=False, default=False)
+    """Allow Action Plan of this Audit be executed in parallel
+       with other Action Plan"""
+
     def __init__(self, **kwargs):
         self.fields = []
         fields = list(objects.Audit.fields)
@@ -356,6 +415,7 @@ class Audit(base.APIBase):
     @classmethod
     def convert_with_links(cls, rpc_audit, expand=True):
         audit = Audit(**rpc_audit.as_dict())
+        hide_fields_in_newer_versions(audit)
         return cls._convert_with_links(audit, pecan.request.host_url, expand)
 
     @classmethod
@@ -364,13 +424,15 @@ class Audit(base.APIBase):
                      name='My Audit',
                      audit_type='ONESHOT',
                      state='PENDING',
-                     created_at=datetime.datetime.utcnow(),
+                     created_at=timeutils.utcnow(),
                      deleted_at=None,
-                     updated_at=datetime.datetime.utcnow(),
+                     updated_at=timeutils.utcnow(),
                      interval='7200',
                      scope=[],
                      auto_trigger=False,
-                     next_run_time=datetime.datetime.utcnow())
+                     next_run_time=timeutils.utcnow(),
+                     start_time=timeutils.utcnow(),
+                     end_time=timeutils.utcnow())
 
         sample.goal_id = '7ae81bb3-dec3-4289-8d6c-da80bd8001ae'
         sample.strategy_id = '7ae81bb3-dec3-4289-8d6c-da80bd8001ff'
@@ -406,6 +468,7 @@ class AuditCollection(collection.Collection):
 
 class AuditsController(rest.RestController):
     """REST controller for Audits."""
+
     def __init__(self):
         super(AuditsController, self).__init__()
         self.dc_client = rpcapi.DecisionEngineAPI()
@@ -471,7 +534,7 @@ class AuditsController(rest.RestController):
         return audits_collection
 
     @wsme_pecan.wsexpose(AuditCollection, types.uuid, int, wtypes.text,
-                         wtypes.text, wtypes.text, wtypes.text, int)
+                         wtypes.text, wtypes.text, wtypes.text)
     def get_all(self, marker=None, limit=None, sort_key='id', sort_dir='asc',
                 goal=None, strategy=None):
         """Retrieve a list of audits.
@@ -507,7 +570,7 @@ class AuditsController(rest.RestController):
         context = pecan.request.context
         policy.enforce(context, 'audit:detail',
                        action='audit:detail')
-        # NOTE(lucasagomes): /detail should only work agaist collections
+        # NOTE(lucasagomes): /detail should only work against collections
         parent = pecan.request.path.split('/')[:-1][-1]
         if parent != "audits":
             raise exception.HTTPNotFound
@@ -534,7 +597,8 @@ class AuditsController(rest.RestController):
 
         return Audit.convert_with_links(rpc_audit)
 
-    @wsme_pecan.wsexpose(Audit, body=AuditPostType, status_code=201)
+    @wsme_pecan.wsexpose(Audit, body=AuditPostType,
+                         status_code=HTTPStatus.CREATED)
     def post(self, audit_p):
         """Create a new audit.
 
@@ -572,6 +636,17 @@ class AuditsController(rest.RestController):
                                       'parameter spec in predefined strategy'))
 
         audit_dict = audit.as_dict()
+        # convert local time to UTC time
+        start_time_value = audit_dict.get('start_time')
+        end_time_value = audit_dict.get('end_time')
+        if start_time_value:
+            audit_dict['start_time'] = start_time_value.replace(
+                tzinfo=tz.tzlocal()).astimezone(
+                    tz.tzutc()).replace(tzinfo=None)
+        if end_time_value:
+            audit_dict['end_time'] = end_time_value.replace(
+                tzinfo=tz.tzlocal()).astimezone(
+                    tz.tzutc()).replace(tzinfo=None)
 
         new_audit = objects.Audit(context, **audit_dict)
         new_audit.create()
@@ -616,6 +691,16 @@ class AuditsController(rest.RestController):
                     reason=error_message % dict(
                         initial_state=initial_state, new_state=new_state))
 
+            patch_path = api_utils.get_patch_key(patch, 'path')
+            if patch_path in ('start_time', 'end_time'):
+                patch_value = api_utils.get_patch_value(patch, patch_path)
+                # convert string format to UTC time
+                new_patch_value = wutils.parse_isodatetime(
+                    patch_value).replace(
+                        tzinfo=tz.tzlocal()).astimezone(
+                            tz.tzutc()).replace(tzinfo=None)
+                api_utils.set_patch_value(patch, patch_path, new_patch_value)
+
             audit = Audit(**api_utils.apply_jsonpatch(audit_dict, patch))
         except api_utils.JSONPATCH_EXCEPTIONS as e:
             raise exception.PatchError(patch=patch, reason=e)
@@ -635,7 +720,7 @@ class AuditsController(rest.RestController):
         audit_to_update.save()
         return Audit.convert_with_links(audit_to_update)
 
-    @wsme_pecan.wsexpose(None, wtypes.text, status_code=204)
+    @wsme_pecan.wsexpose(None, wtypes.text, status_code=HTTPStatus.NO_CONTENT)
     def delete(self, audit):
         """Delete an audit.
 
