@@ -27,7 +27,6 @@ import novaclient.exceptions as nvexceptions
 
 from watcher.common import clients
 from watcher.common import exception
-from watcher.common import utils
 from watcher import conf
 
 LOG = log.getLogger(__name__)
@@ -46,35 +45,92 @@ class NovaHelper(object):
         self.glance = self.osc.glance()
 
     def get_compute_node_list(self):
-        return self.nova.hypervisors.list()
+        hypervisors = self.nova.hypervisors.list()
+        # filter out baremetal nodes from hypervisors
+        compute_nodes = [node for node in hypervisors if
+                         node.hypervisor_type != 'ironic']
+        return compute_nodes
 
-    def get_compute_node_by_id(self, node_id):
-        """Get compute node by ID (*not* UUID)"""
-        # We need to pass an object with an 'id' attribute to make it work
-        return self.nova.hypervisors.get(utils.Struct(id=node_id))
+    def get_compute_node_by_name(self, node_name, servers=False,
+                                 detailed=False):
+        """Search for a hypervisor (compute node) by hypervisor_hostname
+
+        :param node_name: The hypervisor_hostname to search
+        :param servers: If true, include information about servers per
+            hypervisor
+        :param detailed: If true, include information about the compute service
+            per hypervisor (requires microversion 2.53)
+        """
+        return self.nova.hypervisors.search(node_name, servers=servers,
+                                            detailed=detailed)
 
     def get_compute_node_by_hostname(self, node_hostname):
-        """Get compute node by hostname"""
-        try:
-            hypervisors = [hv for hv in self.get_compute_node_list()
-                           if hv.service['host'] == node_hostname]
-            if len(hypervisors) != 1:
-                # TODO(hidekazu)
-                # this may occur if VMware vCenter driver is used
-                raise exception.ComputeNodeNotFound(name=node_hostname)
-            else:
-                compute_nodes = self.nova.hypervisors.search(
-                    hypervisors[0].hypervisor_hostname)
-                if len(compute_nodes) != 1:
-                    raise exception.ComputeNodeNotFound(name=node_hostname)
+        """Get compute node by hostname
 
-                return self.get_compute_node_by_id(compute_nodes[0].id)
+        :param node_hostname: Compute service hostname
+        :returns: novaclient.v2.hypervisors.Hypervisor object if found
+        :raises: ComputeNodeNotFound if no hypervisor is found for the compute
+            service hostname or there was an error communicating with nova
+        """
+        try:
+            # This is a fuzzy match on hypervisor_hostname so we could get back
+            # more than one compute node. If so, match on the compute service
+            # hostname.
+            compute_nodes = self.get_compute_node_by_name(
+                node_hostname, detailed=True)
+            for cn in compute_nodes:
+                if cn.service['host'] == node_hostname:
+                    return cn
+            raise exception.ComputeNodeNotFound(name=node_hostname)
         except Exception as exc:
             LOG.exception(exc)
             raise exception.ComputeNodeNotFound(name=node_hostname)
 
-    def get_instance_list(self):
-        return self.nova.servers.list(search_opts={'all_tenants': True})
+    def get_compute_node_by_uuid(self, node_uuid):
+        """Get compute node by uuid
+
+        :param node_uuid: hypervisor id as uuid after microversion 2.53
+        :returns: novaclient.v2.hypervisors.Hypervisor object if found
+        """
+        return self.nova.hypervisors.get(node_uuid)
+
+    def get_instance_list(self, filters=None, marker=None, limit=-1):
+        """List servers for all tenants with details.
+
+        This always gets servers with the all_tenants=True filter.
+
+        :param filters: Dict of additional filters (optional).
+        :param marker: Get servers that appear later in the server
+                       list than that represented by this server id (optional).
+        :param limit: Maximum number of servers to return (optional).
+                      If limit == -1, all servers will be returned,
+                      note that limit == -1 will have a performance
+                      penalty. For details, please see:
+                      https://bugs.launchpad.net/watcher/+bug/1834679
+        :returns: list of novaclient Server objects
+        """
+        search_opts = {'all_tenants': True}
+        if filters:
+            search_opts.update(filters)
+        return self.nova.servers.list(search_opts=search_opts,
+                                      marker=marker,
+                                      limit=limit)
+
+    def get_instance_by_uuid(self, instance_uuid):
+        return [instance for instance in
+                self.nova.servers.list(search_opts={"all_tenants": True,
+                                                    "uuid": instance_uuid})]
+
+    def get_instance_by_name(self, instance_name):
+        return [instance for instance in
+                self.nova.servers.list(search_opts={"all_tenants": True,
+                                                    "name": instance_name})]
+
+    def get_instances_by_node(self, host):
+        return [instance for instance in
+                self.nova.servers.list(search_opts={"all_tenants": True,
+                                                    "host": host},
+                                       limit=-1)]
 
     def get_flavor_list(self):
         return self.nova.flavors.list(**{'is_public': None})
@@ -163,13 +219,6 @@ class NovaHelper(object):
                 {'instance': instance_id, 'host': host_name})
 
             previous_status = getattr(instance, 'status')
-
-            if (dest_hostname and
-                    not self._check_nova_api_version(self.nova, "2.56")):
-                LOG.error("For migrating a given dest_hostname,"
-                          "Nova API version must be 2.56 or higher")
-                return False
-
             instance.migrate(host=dest_hostname)
             instance = self.nova.servers.get(instance_id)
 
@@ -217,7 +266,7 @@ class NovaHelper(object):
         flavor_id = None
 
         try:
-            flavor_id = self.nova.flavors.get(flavor)
+            flavor_id = self.nova.flavors.get(flavor).id
         except nvexceptions.NotFound:
             flavor_id = [f.id for f in self.nova.flavors.list() if
                          f.name == flavor][0]
@@ -243,9 +292,7 @@ class NovaHelper(object):
                       'OS-EXT-STS:vm_state') != 'resized' \
                 and retry:
             instance = self.nova.servers.get(instance.id)
-            LOG.debug(
-                'Waiting the resize of {0}  to {1}'.format(
-                    instance, flavor_id))
+            LOG.debug('Waiting the resize of %s to %s', instance, flavor_id)
             time.sleep(1)
             retry -= 1
 
@@ -300,8 +347,7 @@ class NovaHelper(object):
             if dest_hostname is None:
                 while (instance.status not in ['ACTIVE', 'ERROR'] and retry):
                     instance = self.nova.servers.get(instance.id)
-                    LOG.debug(
-                        'Waiting the migration of {0}'.format(instance.id))
+                    LOG.debug('Waiting the migration of %s', instance.id)
                     time.sleep(1)
                     retry -= 1
                 new_hostname = getattr(instance, 'OS-EXT-SRV-ATTR:host')
@@ -309,8 +355,8 @@ class NovaHelper(object):
                 if host_name != new_hostname and instance.status == 'ACTIVE':
                     LOG.debug(
                         "Live migration succeeded : "
-                        "instance %s is now on host '%s'.", (
-                            instance_id, new_hostname))
+                        "instance %(instance)s is now on host '%(host)s'.",
+                        {'instance': instance_id, 'host': new_hostname})
                     return True
                 else:
                     return False
@@ -322,11 +368,9 @@ class NovaHelper(object):
                 if not getattr(instance, 'OS-EXT-STS:task_state'):
                     LOG.debug("Instance task state: %s is null", instance_id)
                     break
-                LOG.debug(
-                    'Waiting the migration of {0}  to {1}'.format(
-                        instance,
-                        getattr(instance,
-                                'OS-EXT-SRV-ATTR:host')))
+                LOG.debug('Waiting the migration of %s to %s',
+                          instance,
+                          getattr(instance, 'OS-EXT-SRV-ATTR:host'))
                 time.sleep(1)
                 retry -= 1
 
@@ -405,38 +449,6 @@ class NovaHelper(object):
 
         return status
 
-    def set_host_offline(self, hostname):
-        # See API on https://developer.openstack.org/api-ref/compute/
-        # especially the PUT request
-        # regarding this resource : /v2.1/os-hosts/​{host_name}​
-        #
-        # The following body should be sent :
-        # {
-        # "host": {
-        # "host": "65c5d5b7e3bd44308e67fc50f362aee6",
-        # "maintenance_mode": "off_maintenance",
-        # "status": "enabled"
-        # }
-        # }
-
-        # Voir ici
-        # https://github.com/openstack/nova/
-        # blob/master/nova/virt/xenapi/host.py
-        # set_host_enabled(self, enabled):
-        # Sets the compute host's ability to accept new instances.
-        # host_maintenance_mode(self, host, mode):
-        # Start/Stop host maintenance window.
-        # On start, it triggers guest instances evacuation.
-        host = self.nova.hosts.get(hostname)
-
-        if not host:
-            LOG.debug("host not found: %s", hostname)
-            return False
-        else:
-            host[0].update(
-                {"maintenance_mode": "disable", "status": "disable"})
-            return True
-
     def create_image_from_instance(self, instance_id, image_name,
                                    metadata={"reason": "instance_migrate"}):
         """This method creates a new image from a given instance.
@@ -692,21 +704,6 @@ class NovaHelper(object):
 
         return network_id
 
-    def get_instance_by_uuid(self, instance_uuid):
-        return [instance for instance in
-                self.nova.servers.list(search_opts={"all_tenants": True,
-                                                    "uuid": instance_uuid})]
-
-    def get_instance_by_name(self, instance_name):
-        return [instance for instance in
-                self.nova.servers.list(search_opts={"all_tenants": True,
-                                                    "name": instance_name})]
-
-    def get_instances_by_node(self, host):
-        return [instance for instance in
-                self.nova.servers.list(search_opts={"all_tenants": True})
-                if self.get_hostname(instance) == host]
-
     def get_hostname(self, instance):
         return str(getattr(instance, 'OS-EXT-SRV-ATTR:host'))
 
@@ -723,7 +720,7 @@ class NovaHelper(object):
             instance_id, old_volume.id, new_volume.id)
         while getattr(new_volume, 'status') != 'in-use' and retry:
             new_volume = self.cinder.volumes.get(new_volume.id)
-            LOG.debug('Waiting volume update to {0}'.format(new_volume))
+            LOG.debug('Waiting volume update to %s', new_volume)
             time.sleep(retry_interval)
             retry -= 1
             LOG.debug("retry count: %s", retry)
