@@ -14,17 +14,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import ast
 import collections
 
 from oslo_log import log
 
-from watcher._i18n import _LI, _LW
 from watcher.common import context
 from watcher.decision_engine.loading import default
 from watcher.decision_engine.scoring import scoring_factory
 from watcher import objects
-from watcher.objects import action_plan as apobjects
-from watcher.objects import audit as auditobjects
 
 LOG = log.getLogger(__name__)
 
@@ -80,6 +78,14 @@ class Syncer(object):
         """Strategies loaded from DB"""
         if self._available_strategies is None:
             self._available_strategies = objects.Strategy.list(self.ctx)
+            goal_ids = [g.id for g in self.available_goals]
+            stale_strategies = [s for s in self._available_strategies
+                                if s.goal_id not in goal_ids]
+            for s in stale_strategies:
+                LOG.info("Can't find Goal id %d of strategy %s",
+                         s.goal_id, s.name)
+                s.soft_delete()
+                self._available_strategies.remove(s)
         return self._available_strategies
 
     @property
@@ -137,7 +143,7 @@ class Syncer(object):
 
         for goal_name, goal_map in goals_map.items():
             if goal_map in self.available_goals_map:
-                LOG.info(_LI("Goal %s already exists"), goal_name)
+                LOG.info("Goal %s already exists", goal_name)
                 continue
 
             self.goal_mapping.update(self._sync_goal(goal_map))
@@ -146,14 +152,14 @@ class Syncer(object):
             if (strategy_map in self.available_strategies_map and
                     strategy_map.goal_name not in
                     [g.name for g in self.goal_mapping.values()]):
-                LOG.info(_LI("Strategy %s already exists"), strategy_name)
+                LOG.info("Strategy %s already exists", strategy_name)
                 continue
 
             self.strategy_mapping.update(self._sync_strategy(strategy_map))
 
         for se_name, se_map in scoringengines_map.items():
             if se_map in self.available_scoringengines_map:
-                LOG.info(_LI("Scoring Engine %s already exists"),
+                LOG.info("Scoring Engine %s already exists",
                          se_name)
                 continue
 
@@ -178,7 +184,7 @@ class Syncer(object):
                 indicator._asdict()
                 for indicator in goal_map.efficacy_specification]
             goal.create()
-            LOG.info(_LI("Goal %s created"), goal_name)
+            LOG.info("Goal %s created", goal_name)
 
             # Updating the internal states
             self.available_goals_map[goal] = goal_map
@@ -209,7 +215,7 @@ class Syncer(object):
             strategy.goal_id = objects.Goal.get_by_name(self.ctx, goal_name).id
             strategy.parameters_spec = parameters_spec
             strategy.create()
-            LOG.info(_LI("Strategy %s created"), strategy_name)
+            LOG.info("Strategy %s created", strategy_name)
 
             # Updating the internal states
             self.available_strategies_map[strategy] = strategy_map
@@ -234,7 +240,7 @@ class Syncer(object):
             scoringengine.description = scoringengine_map.description
             scoringengine.metainfo = scoringengine_map.metainfo
             scoringengine.create()
-            LOG.info(_LI("Scoring Engine %s created"), scoringengine_name)
+            LOG.info("Scoring Engine %s created", scoringengine_name)
 
             # Updating the internal states
             self.available_scoringengines_map[scoringengine] = \
@@ -271,17 +277,17 @@ class Syncer(object):
         # and soft delete stale audits and action plans
         for stale_audit_template in self.stale_audit_templates_map.values():
             stale_audit_template.save()
-            LOG.info(_LI("Audit Template '%s' synced"),
+            LOG.info("Audit Template '%s' synced",
                      stale_audit_template.name)
 
         for stale_audit in self.stale_audits_map.values():
             stale_audit.save()
-            LOG.info(_LI("Stale audit '%s' synced and cancelled"),
+            LOG.info("Stale audit '%s' synced and cancelled",
                      stale_audit.uuid)
 
         for stale_action_plan in self.stale_action_plans_map.values():
             stale_action_plan.save()
-            LOG.info(_LI("Stale action plan '%s' synced and cancelled"),
+            LOG.info("Stale action plan '%s' synced and cancelled",
                      stale_action_plan.uuid)
 
     def _find_stale_audit_templates_due_to_goal(self):
@@ -320,7 +326,7 @@ class Syncer(object):
         for goal_id, synced_goal in self.goal_mapping.items():
             filters = {"goal_id": goal_id}
             stale_audits = objects.Audit.list(
-                self.ctx, filters=filters)
+                self.ctx, filters=filters, eager=True)
 
             # Update the goal ID for the stale audits (w/o saving)
             for audit in stale_audits:
@@ -333,54 +339,57 @@ class Syncer(object):
     def _find_stale_audits_due_to_strategy(self):
         for strategy_id, synced_strategy in self.strategy_mapping.items():
             filters = {"strategy_id": strategy_id}
-            stale_audits = objects.Audit.list(self.ctx, filters=filters)
+            stale_audits = objects.Audit.list(
+                self.ctx, filters=filters, eager=True)
             # Update strategy IDs for all stale audits (w/o saving)
             for audit in stale_audits:
                 if audit.id not in self.stale_audits_map:
                     audit.strategy_id = synced_strategy.id
-                    audit.state = auditobjects.State.CANCELLED
+                    audit.state = objects.audit.State.CANCELLED
                     self.stale_audits_map[audit.id] = audit
                 else:
                     self.stale_audits_map[
                         audit.id].strategy_id = synced_strategy.id
                     self.stale_audits_map[
-                        audit.id].state = auditobjects.State.CANCELLED
+                        audit.id].state = objects.audit.State.CANCELLED
 
     def _find_stale_action_plans_due_to_strategy(self):
         for strategy_id, synced_strategy in self.strategy_mapping.items():
             filters = {"strategy_id": strategy_id}
             stale_action_plans = objects.ActionPlan.list(
-                self.ctx, filters=filters)
+                self.ctx, filters=filters, eager=True)
 
             # Update strategy IDs for all stale action plans (w/o saving)
             for action_plan in stale_action_plans:
                 if action_plan.id not in self.stale_action_plans_map:
                     action_plan.strategy_id = synced_strategy.id
-                    action_plan.state = apobjects.State.CANCELLED
+                    action_plan.state = objects.action_plan.State.CANCELLED
                     self.stale_action_plans_map[action_plan.id] = action_plan
                 else:
                     self.stale_action_plans_map[
                         action_plan.id].strategy_id = synced_strategy.id
                     self.stale_action_plans_map[
-                        action_plan.id].state = apobjects.State.CANCELLED
+                        action_plan.id].state = (
+                            objects.action_plan.State.CANCELLED)
 
     def _find_stale_action_plans_due_to_audit(self):
         for audit_id, synced_audit in self.stale_audits_map.items():
             filters = {"audit_id": audit_id}
             stale_action_plans = objects.ActionPlan.list(
-                self.ctx, filters=filters)
+                self.ctx, filters=filters, eager=True)
 
             # Update audit IDs for all stale action plans (w/o saving)
             for action_plan in stale_action_plans:
                 if action_plan.id not in self.stale_action_plans_map:
                     action_plan.audit_id = synced_audit.id
-                    action_plan.state = apobjects.State.CANCELLED
+                    action_plan.state = objects.action_plan.State.CANCELLED
                     self.stale_action_plans_map[action_plan.id] = action_plan
                 else:
                     self.stale_action_plans_map[
                         action_plan.id].audit_id = synced_audit.id
                     self.stale_action_plans_map[
-                        action_plan.id].state = apobjects.State.CANCELLED
+                        action_plan.id].state = (
+                            objects.action_plan.State.CANCELLED)
 
     def _soft_delete_removed_goals(self):
         removed_goals = [
@@ -393,20 +402,21 @@ class Syncer(object):
             invalid_ats = objects.AuditTemplate.list(self.ctx, filters=filters)
             for at in invalid_ats:
                 LOG.warning(
-                    _LW("Audit Template '%(audit_template)s' references a "
-                        "goal that does not exist"), audit_template=at.uuid)
+                    "Audit Template '%(audit_template)s' references a "
+                    "goal that does not exist", audit_template=at.uuid)
 
-            stale_audits = objects.Audit.list(self.ctx, filters=filters)
+            stale_audits = objects.Audit.list(
+                self.ctx, filters=filters, eager=True)
             for audit in stale_audits:
                 LOG.warning(
-                    _LW("Audit '%(audit)s' references a "
-                        "goal that does not exist"), audit=audit.uuid)
+                    "Audit '%(audit)s' references a "
+                    "goal that does not exist", audit=audit.uuid)
                 if audit.id not in self.stale_audits_map:
-                    audit.state = auditobjects.State.CANCELLED
+                    audit.state = objects.audit.State.CANCELLED
                     self.stale_audits_map[audit.id] = audit
                 else:
                     self.stale_audits_map[
-                        audit.id].state = auditobjects.State.CANCELLED
+                        audit.id].state = objects.audit.State.CANCELLED
 
     def _soft_delete_removed_strategies(self):
         removed_strategies = [
@@ -419,8 +429,8 @@ class Syncer(object):
             invalid_ats = objects.AuditTemplate.list(self.ctx, filters=filters)
             for at in invalid_ats:
                 LOG.info(
-                    _LI("Audit Template '%(audit_template)s' references a "
-                        "strategy that does not exist"),
+                    "Audit Template '%(audit_template)s' references a "
+                    "strategy that does not exist",
                     audit_template=at.uuid)
                 # In this case we can reset the strategy ID to None
                 # so the audit template can still achieve the same goal
@@ -431,38 +441,40 @@ class Syncer(object):
                 else:
                     self.stale_audit_templates_map[at.id].strategy_id = None
 
-            stale_audits = objects.Audit.list(self.ctx, filters=filters)
+            stale_audits = objects.Audit.list(
+                self.ctx, filters=filters, eager=True)
             for audit in stale_audits:
                 LOG.warning(
-                    _LW("Audit '%(audit)s' references a "
-                        "strategy that does not exist"), audit=audit.uuid)
+                    "Audit '%(audit)s' references a "
+                    "strategy that does not exist", audit=audit.uuid)
                 if audit.id not in self.stale_audits_map:
-                    audit.state = auditobjects.State.CANCELLED
+                    audit.state = objects.audit.State.CANCELLED
                     self.stale_audits_map[audit.id] = audit
                 else:
                     self.stale_audits_map[
-                        audit.id].state = auditobjects.State.CANCELLED
+                        audit.id].state = objects.audit.State.CANCELLED
 
             stale_action_plans = objects.ActionPlan.list(
-                self.ctx, filters=filters)
+                self.ctx, filters=filters, eager=True)
             for action_plan in stale_action_plans:
                 LOG.warning(
-                    _LW("Action Plan '%(action_plan)s' references a "
-                        "strategy that does not exist"),
+                    "Action Plan '%(action_plan)s' references a "
+                    "strategy that does not exist",
                     action_plan=action_plan.uuid)
                 if action_plan.id not in self.stale_action_plans_map:
-                    action_plan.state = apobjects.State.CANCELLED
+                    action_plan.state = objects.action_plan.State.CANCELLED
                     self.stale_action_plans_map[action_plan.id] = action_plan
                 else:
                     self.stale_action_plans_map[
-                        action_plan.id].state = apobjects.State.CANCELLED
+                        action_plan.id].state = (
+                            objects.action_plan.State.CANCELLED)
 
     def _soft_delete_removed_scoringengines(self):
         removed_se = [
             se for se in self.available_scoringengines
             if se.name not in self.discovered_map['scoringengines']]
         for se in removed_se:
-            LOG.info(_LI("Scoring Engine %s removed"), se.name)
+            LOG.info("Scoring Engine %s removed", se.name)
             se.soft_delete()
 
     def _discover(self):
@@ -521,9 +533,9 @@ class Syncer(object):
         for matching_goal in matching_goals:
             if (matching_goal.efficacy_specification == goal_efficacy_spec and
                     matching_goal.display_name == goal_display_name):
-                LOG.info(_LI("Goal %s unchanged"), goal_name)
+                LOG.info("Goal %s unchanged", goal_name)
             else:
-                LOG.info(_LI("Goal %s modified"), goal_name)
+                LOG.info("Goal %s modified", goal_name)
                 matching_goal.soft_delete()
                 stale_goals.append(matching_goal)
 
@@ -532,14 +544,17 @@ class Syncer(object):
     def _soft_delete_stale_strategies(self, strategy_map, matching_strategies):
         strategy_name = strategy_map.name
         strategy_display_name = strategy_map.display_name
+        parameters_spec = strategy_map.parameters_spec
 
         stale_strategies = []
         for matching_strategy in matching_strategies:
             if (matching_strategy.display_name == strategy_display_name and
-                    matching_strategy.goal_id not in self.goal_mapping):
-                LOG.info(_LI("Strategy %s unchanged"), strategy_name)
+                    matching_strategy.goal_id not in self.goal_mapping and
+                    matching_strategy.parameters_spec ==
+                    ast.literal_eval(parameters_spec)):
+                LOG.info("Strategy %s unchanged", strategy_name)
             else:
-                LOG.info(_LI("Strategy %s modified"), strategy_name)
+                LOG.info("Strategy %s modified", strategy_name)
                 matching_strategy.soft_delete()
                 stale_strategies.append(matching_strategy)
 
@@ -555,9 +570,9 @@ class Syncer(object):
         for matching_scoringengine in matching_scoringengines:
             if (matching_scoringengine.description == se_description and
                     matching_scoringengine.metainfo == se_metainfo):
-                LOG.info(_LI("Scoring Engine %s unchanged"), se_name)
+                LOG.info("Scoring Engine %s unchanged", se_name)
             else:
-                LOG.info(_LI("Scoring Engine %s modified"), se_name)
+                LOG.info("Scoring Engine %s modified", se_name)
                 matching_scoringengine.soft_delete()
                 stale_scoringengines.append(matching_scoringengine)
 
