@@ -15,6 +15,7 @@ import itertools
 from unittest import mock
 from urllib import parse as urlparse
 
+from http import HTTPStatus
 from oslo_config import cfg
 from oslo_serialization import jsonutils
 from oslo_utils import timeutils
@@ -126,7 +127,7 @@ class TestListAuditTemplate(FunctionalTestWithSetup):
         response = self.get_json(
             '/audit_templates/%s' % audit_template['uuid'],
             expect_errors=True)
-        self.assertEqual(404, response.status_int)
+        self.assertEqual(HTTPStatus.NOT_FOUND, response.status_int)
 
     def test_detail(self):
         audit_template = obj_utils.create_test_audit_template(self.context)
@@ -152,7 +153,7 @@ class TestListAuditTemplate(FunctionalTestWithSetup):
         response = self.get_json(
             '/audit_templates/%s/detail' % audit_template['uuid'],
             expect_errors=True)
-        self.assertEqual(404, response.status_int)
+        self.assertEqual(HTTPStatus.NOT_FOUND, response.status_int)
 
     def test_many(self):
         audit_template_list = []
@@ -215,9 +216,10 @@ class TestListAuditTemplate(FunctionalTestWithSetup):
         self.assertIn('links', response.keys())
         self.assertEqual(2, len(response['links']))
         self.assertIn(uuid, response['links'][0]['href'])
-        for l in response['links']:
-            bookmark = l['rel'] == 'bookmark'
-            self.assertTrue(self.validate_link(l['href'], bookmark=bookmark))
+        for link in response['links']:
+            bookmark = link['rel'] == 'bookmark'
+            self.assertTrue(
+                self.validate_link(link['href'], bookmark=bookmark))
 
     def test_collection_links(self):
         for id_ in range(5):
@@ -336,7 +338,7 @@ class TestListAuditTemplate(FunctionalTestWithSetup):
         response = self.get_json(
             '/audit_templates?sort_key=%s' % 'goal_bad_name',
             expect_errors=True)
-        self.assertEqual(400, response.status_int)
+        self.assertEqual(HTTPStatus.BAD_REQUEST, response.status_int)
 
 
 class TestPatch(FunctionalTestWithSetup):
@@ -362,7 +364,7 @@ class TestPatch(FunctionalTestWithSetup):
             [{'path': '/goal', 'value': new_goal_uuid,
               'op': 'replace'}])
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(200, response.status_code)
+        self.assertEqual(HTTPStatus.OK, response.status_code)
 
         response = self.get_json(
             '/audit_templates/%s' % self.audit_template.uuid)
@@ -386,7 +388,7 @@ class TestPatch(FunctionalTestWithSetup):
             [{'path': '/goal', 'value': new_goal_uuid,
               'op': 'replace'}])
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(200, response.status_code)
+        self.assertEqual(HTTPStatus.OK, response.status_code)
 
         response = self.get_json(
             '/audit_templates/%s' % self.audit_template.name)
@@ -401,7 +403,7 @@ class TestPatch(FunctionalTestWithSetup):
             [{'path': '/goal', 'value': self.fake_goal1.uuid,
               'op': 'replace'}],
             expect_errors=True)
-        self.assertEqual(404, response.status_int)
+        self.assertEqual(HTTPStatus.NOT_FOUND, response.status_int)
         self.assertEqual('application/json', response.content_type)
         self.assertTrue(response.json['error_message'])
 
@@ -416,7 +418,7 @@ class TestPatch(FunctionalTestWithSetup):
                 [{'path': '/goal', 'value': utils.generate_uuid(),
                   'op': 'replace'}],
                 expect_errors=True)
-        self.assertEqual(400, response.status_int)
+        self.assertEqual(HTTPStatus.BAD_REQUEST, response.status_int)
         assert not cn_mock.called
 
     def test_add_goal_uuid(self):
@@ -426,7 +428,7 @@ class TestPatch(FunctionalTestWithSetup):
               'value': self.fake_goal2.uuid,
               'op': 'add'}])
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(200, response.status_int)
+        self.assertEqual(HTTPStatus.OK, response.status_int)
 
         response = self.get_json(
             '/audit_templates/%s' % self.audit_template.uuid)
@@ -439,7 +441,7 @@ class TestPatch(FunctionalTestWithSetup):
               'value': self.fake_strategy1.uuid,
               'op': 'add'}])
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(200, response.status_int)
+        self.assertEqual(HTTPStatus.OK, response.status_int)
 
         response = self.get_json(
             '/audit_templates/%s' % self.audit_template.uuid)
@@ -452,7 +454,7 @@ class TestPatch(FunctionalTestWithSetup):
               'value': self.fake_strategy2['uuid'],
               'op': 'replace'}])
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(200, response.status_int)
+        self.assertEqual(HTTPStatus.OK, response.status_int)
 
         response = self.get_json(
             '/audit_templates/%s' % self.audit_template.uuid)
@@ -466,7 +468,7 @@ class TestPatch(FunctionalTestWithSetup):
               'value': utils.generate_uuid(),  # Does not exist
               'op': 'replace'}], expect_errors=True)
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(400, response.status_int)
+        self.assertEqual(HTTPStatus.BAD_REQUEST, response.status_int)
         self.assertTrue(response.json['error_message'])
 
     def test_add_non_existent_property(self):
@@ -475,7 +477,7 @@ class TestPatch(FunctionalTestWithSetup):
             [{'path': '/foo', 'value': 'bar', 'op': 'add'}],
             expect_errors=True)
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(400, response.status_int)
+        self.assertEqual(HTTPStatus.BAD_REQUEST, response.status_int)
         self.assertTrue(response.json['error_message'])
 
     def test_remove_strategy(self):
@@ -492,7 +494,7 @@ class TestPatch(FunctionalTestWithSetup):
             '/audit_templates/%s' % self.audit_template.uuid,
             [{'path': '/strategy', 'op': 'remove'}])
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(200, response.status_code)
+        self.assertEqual(HTTPStatus.OK, response.status_code)
 
     def test_remove_goal(self):
         response = self.get_json(
@@ -503,7 +505,7 @@ class TestPatch(FunctionalTestWithSetup):
             '/audit_templates/%s' % self.audit_template.uuid,
             [{'path': '/goal', 'op': 'remove'}],
             expect_errors=True)
-        self.assertEqual(403, response.status_code)
+        self.assertEqual(HTTPStatus.FORBIDDEN, response.status_code)
         self.assertEqual('application/json', response.content_type)
         self.assertTrue(response.json['error_message'])
 
@@ -512,7 +514,7 @@ class TestPatch(FunctionalTestWithSetup):
             '/audit_templates/%s' % self.audit_template.uuid,
             [{'path': '/uuid', 'op': 'remove'}],
             expect_errors=True)
-        self.assertEqual(400, response.status_int)
+        self.assertEqual(HTTPStatus.BAD_REQUEST, response.status_int)
         self.assertEqual('application/json', response.content_type)
         self.assertTrue(response.json['error_message'])
 
@@ -521,7 +523,7 @@ class TestPatch(FunctionalTestWithSetup):
             '/audit_templates/%s' % self.audit_template.uuid,
             [{'path': '/non-existent', 'op': 'remove'}],
             expect_errors=True)
-        self.assertEqual(400, response.status_code)
+        self.assertEqual(HTTPStatus.BAD_REQUEST, response.status_code)
         self.assertEqual('application/json', response.content_type)
         self.assertTrue(response.json['error_message'])
 
@@ -538,7 +540,7 @@ class TestPost(FunctionalTestWithSetup):
 
         response = self.post_json('/audit_templates', audit_template_dict)
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(201, response.status_int)
+        self.assertEqual(HTTPStatus.CREATED, response.status_int)
         # Check location header
         self.assertIsNotNone(response.location)
         expected_location = \
@@ -565,7 +567,7 @@ class TestPost(FunctionalTestWithSetup):
 
         response = self.post_json('/audit_templates', audit_template_dict)
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(201, response.status_int)
+        self.assertEqual(HTTPStatus.CREATED, response.status_int)
         # Check location header
         self.assertIsNotNone(response.location)
         expected_location = \
@@ -613,7 +615,8 @@ class TestPost(FunctionalTestWithSetup):
             strategy=self.fake_strategy1.uuid, scope=scope)
         response = self.post_json('/audit_templates',
                                   audit_template_dict, expect_errors=True)
-        self.assertEqual(500, response.status_int)
+        self.assertEqual(HTTPStatus.INTERNAL_SERVER_ERROR,
+                         response.status_int)
 
     def test_create_audit_template_does_autogenerate_id(self):
         audit_template_dict = post_get_test_audit_template(
@@ -635,7 +638,7 @@ class TestPost(FunctionalTestWithSetup):
 
         response = self.post_json('/audit_templates', audit_template_dict)
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(201, response.status_int)
+        self.assertEqual(HTTPStatus.CREATED, response.status_int)
         self.assertTrue(utils.is_uuid_like(response.json['uuid']))
 
     def test_create_audit_template_with_invalid_goal(self):
@@ -648,7 +651,7 @@ class TestPost(FunctionalTestWithSetup):
                 goal_uuid=utils.generate_uuid())
             response = self.post_json('/audit_templates',
                                       audit_template_dict, expect_errors=True)
-        self.assertEqual(400, response.status_int)
+        self.assertEqual(HTTPStatus.BAD_REQUEST, response.status_int)
         assert not cn_mock.called
 
     def test_create_audit_template_with_invalid_strategy(self):
@@ -662,7 +665,7 @@ class TestPost(FunctionalTestWithSetup):
                 strategy_uuid=utils.generate_uuid())
             response = self.post_json('/audit_templates',
                                       audit_template_dict, expect_errors=True)
-        self.assertEqual(400, response.status_int)
+        self.assertEqual(HTTPStatus.BAD_REQUEST, response.status_int)
         assert not cn_mock.called
 
     def test_create_audit_template_with_unrelated_strategy(self):
@@ -676,7 +679,7 @@ class TestPost(FunctionalTestWithSetup):
                 strategy=self.fake_strategy2['uuid'])
             response = self.post_json('/audit_templates',
                                       audit_template_dict, expect_errors=True)
-        self.assertEqual(400, response.status_int)
+        self.assertEqual(HTTPStatus.BAD_REQUEST, response.status_int)
         assert not cn_mock.called
 
     def test_create_audit_template_with_uuid(self):
@@ -689,7 +692,7 @@ class TestPost(FunctionalTestWithSetup):
             response = self.post_json('/audit_templates', audit_template_dict,
                                       expect_errors=True)
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(400, response.status_int)
+        self.assertEqual(HTTPStatus.BAD_REQUEST, response.status_int)
         assert not cn_mock.called
 
     def test_create_audit_template_with_old_scope(self):
@@ -710,7 +713,7 @@ class TestPost(FunctionalTestWithSetup):
             strategy=self.fake_strategy1.uuid, scope=scope)
         response = self.post_json('/audit_templates',
                                   audit_template_dict)
-        self.assertEqual(201, response.status_int)
+        self.assertEqual(HTTPStatus.CREATED, response.status_int)
 
 
 class TestDelete(api_base.FunctionalTest):
@@ -730,7 +733,7 @@ class TestDelete(api_base.FunctionalTest):
         response = self.get_json(
             urlparse.quote('/audit_templates/%s' % self.audit_template.uuid),
             expect_errors=True)
-        self.assertEqual(404, response.status_int)
+        self.assertEqual(HTTPStatus.NOT_FOUND, response.status_int)
         self.assertEqual('application/json', response.content_type)
         self.assertTrue(response.json['error_message'])
 
@@ -753,7 +756,7 @@ class TestDelete(api_base.FunctionalTest):
         response = self.get_json(
             urlparse.quote('/audit_templates/%s' % self.audit_template.name),
             expect_errors=True)
-        self.assertEqual(404, response.status_int)
+        self.assertEqual(HTTPStatus.NOT_FOUND, response.status_int)
         self.assertEqual('application/json', response.content_type)
         self.assertTrue(response.json['error_message'])
 
@@ -771,7 +774,7 @@ class TestDelete(api_base.FunctionalTest):
         uuid = utils.generate_uuid()
         response = self.delete(
             '/audit_templates/%s' % uuid, expect_errors=True)
-        self.assertEqual(404, response.status_int)
+        self.assertEqual(HTTPStatus.NOT_FOUND, response.status_int)
         self.assertEqual('application/json', response.content_type)
         self.assertTrue(response.json['error_message'])
 
@@ -782,9 +785,9 @@ class TestAuditTemplatePolicyEnforcement(api_base.FunctionalTest):
         self.policy.set_rules({
             "admin_api": "(role:admin or role:administrator)",
             "default": "rule:admin_api",
-            rule: "rule:defaut"})
+            rule: "rule:default"})
         response = func(*arg, **kwarg)
-        self.assertEqual(403, response.status_int)
+        self.assertEqual(HTTPStatus.FORBIDDEN, response.status_int)
         self.assertEqual('application/json', response.content_type)
         self.assertTrue(
             "Policy doesn't allow %s to be performed." % rule,
