@@ -70,7 +70,7 @@ def create_test_audit_template(**kwargs):
     :param kwargs: kwargsargs with overriding values for audit template's
                    attributes.
     :returns: Test AuditTemplate DB object.
-    """
+    """  # noqa: E501
     audit_template = get_test_audit_template(**kwargs)
     # Let DB generate ID if it isn't specified explicitly
     if 'id' not in kwargs:
@@ -97,6 +97,10 @@ def get_test_audit(**kwargs):
         'auto_trigger': kwargs.get('auto_trigger', False),
         'next_run_time': kwargs.get('next_run_time'),
         'hostname': kwargs.get('hostname', 'host_1'),
+        'start_time': kwargs.get('start_time'),
+        'end_time': kwargs.get('end_time'),
+        'force': kwargs.get('force', False)
+
     }
     # ObjectField doesn't allow None nor dict, so if we want to simulate a
     # non-eager object loading, the field should not be referenced at all.
