@@ -144,7 +144,7 @@ class TestZoneMigration(TestBaseStrategy):
 
     @staticmethod
     def fake_volume(**kwargs):
-        volume = mock.MagicMock(spec=cinderclient.v2.volumes.Volume)
+        volume = mock.MagicMock(spec=cinderclient.v3.volumes.Volume)
         volume.id = kwargs.get('id', utils.generate_uuid())
         volume.name = kwargs.get('name', 'fake_name')
         volume.status = kwargs.get('status', 'available')
@@ -464,11 +464,11 @@ class TestZoneMigration(TestBaseStrategy):
         }
         filters = self.strategy.get_priority_filter_list()
         self.assertIn(strategies.zone_migration.ComputeHostSortFilter,
-                      map(lambda l: l.__class__, filters))
+                      map(lambda l: l.__class__, filters))  # noqa: E741
         self.assertIn(strategies.zone_migration.StorageHostSortFilter,
-                      map(lambda l: l.__class__, filters))
+                      map(lambda l: l.__class__, filters))  # noqa: E741
         self.assertIn(strategies.zone_migration.ProjectSortFilter,
-                      map(lambda l: l.__class__, filters))
+                      map(lambda l: l.__class__, filters))  # noqa: E741
 
     # ComputeHostSortFilter #
 
